Metadata bundle — Invenio 3.4.0a8 documentation

# Metadata bundle

The metadata bundle contains all modules related to records and metadata management including e.g. records storage, persistent identifier management, search engine indexing, an OAI-PMH server and REST APIs for records.

Included modules:

- invenio-indexer

    - Highly scalable record bulk indexing.

- invenio-jsonschemas

    - JSONSchema registry for Invenio.

- invenio-oaiserver

    - OAI-PMH server implementation for Invenio.

- invenio-pidstore

    - Management, registration and resolution of persistent identifiers including e.g DOIs.

- invenio-records

    - JSON document storage with revision history and JSONSchema validation.

- invenio-records-rest

    - REST APIs for search and CRUD operations on records and persistent identifiers.

- invenio-records-ui

    - User interface for displaying records.

- invenio-search

    - Elasticsearch integration module for Invenio.

- invenio-search-js

    - AngularJS search application for displaying records from the REST API.

- invenio-search-ui

    - User interface for searching records.